---
title: Locus to Gene (L2G)
---

::: gentropy.l2g.LocusToGeneFeatureMatrixStep

::: gentropy.l2g.LocusToGeneStep

::: gentropy.l2g.LocusToGeneEvidenceStep

::: gentropy.l2g.LocusToGeneAssociationsStep
